command

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 23, 2022 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExecuteLoginSuccess

func ExecuteLoginSuccess() tea.Cmd

func ExecuteRetrieveData

func ExecuteRetrieveData() tea.Cmd

ExecuteRetrieveData defines a custom command for bubbletea, which notifies the components to retrieve their data.

func ExecuteShutdown

func ExecuteShutdown() tea.Cmd

ExecuteShutdown defines a custom command for bubbletea, which allows us to define a shutdown hook. We call ExecuteShutdown on commands like "q", "^C" or "ESC" and handle it centralized in the main model.

Types

type LoginSuccess

type LoginSuccess struct{}

type RetrieveData

type RetrieveData struct{}

type Shutdown

type Shutdown struct{}

Jump to