Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExecuteLoginSuccess ¶
func ExecuteRetrieveData ¶
ExecuteRetrieveData defines a custom command for bubbletea, which notifies the components to retrieve their data.
func ExecuteShutdown ¶
ExecuteShutdown defines a custom command for bubbletea, which allows us to define a shutdown hook. We call ExecuteShutdown on commands like "q", "^C" or "ESC" and handle it centralized in the main model.
Types ¶
type LoginSuccess ¶
type LoginSuccess struct{}
type RetrieveData ¶
type RetrieveData struct{}
Click to show internal directories.
Click to hide internal directories.